@@ -188,7 +188,7 @@ void cdrdao_toc_info(char *filename)
 	   long start = 0;
 	   for (i = 0; i < ARRAYSIZE(album_info); i++) {
 	       char *str;
-	       str = gtk_entry_get_text(GTK_ENTRY(album_info[i].widget));
+	       str = (char *)gtk_entry_get_text(GTK_ENTRY(album_info[i].widget));
 		  /* +2 for null at end of both strings*/
 	       new_cdtext_length += strlen(str) + strlen(album_info[i].fieldid) + 2 ;
 	       if (strlen(album_info[i].init) == 0 && !only_blank(str))
@@ -197,7 +197,7 @@ void cdrdao_toc_info(char *filename)
 	   for (j = 0; j < num_song_markers+1; j++) {
 	      for (i = 0; i < ARRAYSIZE(song_info); i++) {
 		  char *str;
-		  str = gtk_entry_get_text(GTK_ENTRY(song_widget[j][i]));
+		  str = (char *)gtk_entry_get_text(GTK_ENTRY(song_widget[j][i]));
 		     /* We add 3 digit song # to fieldid when storing */
 		  new_cdtext_length += strlen(str) + strlen(song_info[i].fieldid) + 3 + 2;
 		  if (!only_blank(str))
@@ -211,7 +211,7 @@ void cdrdao_toc_info(char *filename)
 	      fprintf(toc, "   LANGUAGE 0 {\n");
 	      for (i = 0; i < ARRAYSIZE(album_info); i++) {
 		 char *str;
-		 str = gtk_entry_get_text(GTK_ENTRY(album_info[i].widget));
+		 str = (char *)gtk_entry_get_text(GTK_ENTRY(album_info[i].widget));
 		 if (!only_blank(str)) {
 		       /* First entry, language added to file above */
 		    if (i > 0) {
@@ -237,7 +237,7 @@ void cdrdao_toc_info(char *filename)
 		 fprintf(toc, "   CD_TEXT {\n      LANGUAGE 0 {\n");
 		 for (i = 0; i < ARRAYSIZE(song_info); i++) {
 		    char *str;
-		    str = gtk_entry_get_text(GTK_ENTRY(song_widget[j][i]));
+		    str = (char *)gtk_entry_get_text(GTK_ENTRY(song_widget[j][i]));
 		    if (!only_blank(str)) {
 		       fprintf(toc, "         %s \"%s\"\n", song_info[i].fieldid, str);
 			  /* Duplicated above */
